package com.chinapnr.android.adapay_android;

import android.annotation.SuppressLint;
import android.content.Intent;
import android.graphics.Color;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.text.Spannable;
import android.text.SpannableString;
import android.text.style.ForegroundColorSpan;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.PopupWindow;
import android.widget.TextView;
import android.widget.Toast;

import com.alibaba.fastjson.JSON;
import com.chinapnr.android.adapay.AdaPay;
import com.chinapnr.android.adapay.PayCallback;
import com.chinapnr.android.adapay.bean.Payment;
import com.chinapnr.android.adapay.bean.PayResult;
import com.chinapnr.android.adapay.bean.PayType;
import com.chinapnr.android.adapay_android.beans.respbean.BaseRespBean;
import com.chinapnr.android.adapay_android.network.PayNetWorkCallback;
import com.chinapnr.android.adapay_android.widgets.CustomTextView;
import com.chinapnr.android.adapay_android.widgets.DialogManager;

public class AppPayActivity extends AppCompatActivity implements View.OnClickListener {

    private String payType;
    private PopupWindow payTypeWindow;

    private TextView tvAmount;
    private TextView tvPayType;
    private TextView tvDoPay;
    //第一次显示界面，不发起支付请求
    private boolean isFirstInit;

    //标识此页面是否走过 onStop 生命周期
    private boolean isStop;

    private ImageView ivAplipayCheck;
    private ImageView ivWechatCheck;

    private PayResult payResult;
    private Payment paymentObj;
    //获取订单信息回调
    private PayNetWorkCallback callback = new PayNetWorkCallback<BaseRespBean>() {
        @Override
        public void onSuccess(BaseRespBean respObj) {


            if (respObj == null) {
                DialogManager.dismiss();
                Toast.makeText(AppPayActivity.this, "支付信息为空", Toast.LENGTH_SHORT).show();
                return;
            }
            paymentObj = JSON.parseObject(respObj.getPayment(), Payment.class);

            if (paymentObj == null) {
                DialogManager.dismiss();
                return;
            }

            if (isFirstInit) {
                DialogManager.dismiss();
                Spannable string = new SpannableString("总计：¥ " + paymentObj.getPay_amt());
                string.setSpan(new ForegroundColorSpan(Color.RED), 3, string.length(), Spannable.SPAN_EXCLUSIVE_EXCLUSIVE);
                tvAmount.setText(string);
                isFirstInit = false;
            } else {

                AdaPay.doPay(AppPayActivity.this, 60, respObj.getPayment(), new PayCallback() {
                    @Override
                    public void onPayment(PayResult payResult) {

                        DialogManager.dismiss();
                        //由于支付时离开了页面这里先保存支付结果
                        AppPayActivity.this.payResult = payResult;

                        if (isStop) {
                            return;
                        }

                        startToResultAvtivity();
                    }
                });
            }
        }

        @Override
        public void onFail(BaseRespBean respObj) {
            DialogManager.dismiss();
            Toast.makeText(AppPayActivity.this, "支付失败", Toast.LENGTH_SHORT).show();
        }

        @Override
        public void onFail(String respMsg) {
            DialogManager.dismiss();
            Toast.makeText(AppPayActivity.this, respMsg, Toast.LENGTH_SHORT).show();
        }
    };

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_app_pay);

        initView();

        isFirstInit = true;
        //获取订单信息
        TradeRequest.requestPayment(this, PayType.ALIPAY, callback);
    }

    private void initView() {

        findViewById(R.id.iv_back).setOnClickListener(this);
        ((TextView) findViewById(R.id.tv_title)).setText("订单支付");

        tvAmount = findViewById(R.id.tv_amount);
        tvPayType = findViewById(R.id.tv_choose_pay_method);
        tvDoPay = findViewById(R.id.tv_do_pay);
        findViewById(R.id.layout_choose_method).setOnClickListener(this);

        tvAmount.setOnClickListener(this);
        tvDoPay.setOnClickListener(this);
    }

    @Override
    protected void onStart() {
        super.onStart();
        isStop = false;

        if (payResult != null) {
            startToResultAvtivity();
        }

    }

    private void startToResultAvtivity() {
        Intent intent = new Intent(AppPayActivity.this, PayResultActivity.class);
        intent.putExtra(PayResultActivity.PAYMENT_INFO, paymentObj);
        intent.putExtra(PayResultActivity.TRADE_CODE, payResult.getResultCode());
        intent.putExtra(PayResultActivity.TRADE_MSG, payResult.getResultMsg());
        startActivity(intent);
        finish();
    }

    /**
     * 显示付款方式的悬浮窗
     */
    private void showPopWindow() {
        @SuppressLint("InflateParams") View view = LayoutInflater.from(this).inflate(R.layout.pay_type_window_layout, null, false);

        CustomTextView tvAlipay = view.findViewById(R.id.cus_tv_alipay);
        CustomTextView tvWechat = view.findViewById(R.id.cus_tv_wechat);
        ivAplipayCheck = tvAlipay.getIvRightIcon();
        ivWechatCheck = tvWechat.getIvRightIcon();
        ivAplipayCheck.setVisibility(View.GONE);
        ivWechatCheck.setVisibility(View.GONE);

        tvAlipay.setOnClickListener(this);
        tvWechat.setOnClickListener(this);

        //1.构造一个PopupWindow，参数依次是加载的View，宽高
        payTypeWindow = new PopupWindow(view,
                ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.WRAP_CONTENT, true);


        view.measure(View.MeasureSpec.UNSPECIFIED, View.MeasureSpec.UNSPECIFIED);
        int popupHeight = view.getMeasuredHeight();
        int popupWidth = view.getMeasuredWidth();
        int[] location = new int[2];
        tvAmount.getLocationOnScreen(location);
        //在控件上方显示
        payTypeWindow.showAtLocation(tvAmount, Gravity.NO_GRAVITY, (location[0]) - popupWidth / 2, location[1] - popupHeight);
    }

    @Override
    public void onClick(View view) {

        int viewId = view.getId();

        switch (viewId) {
            case R.id.iv_back:
                finish();
                break;

            case R.id.layout_choose_method:
                showPopWindow();
                break;

            case R.id.tv_do_pay:

                if (PayType.WX.equals(payType)) {
                    Toast.makeText(this, "微信支付敬请期待", Toast.LENGTH_SHORT).show();
                    return;
                }

                //获取订单信息
                TradeRequest.requestPayment(this, payType, callback);
                break;

            case R.id.cus_tv_alipay:

                ivAplipayCheck.setVisibility(View.VISIBLE);
                ivWechatCheck.setVisibility(View.GONE);

                payType = PayType.ALIPAY;
                tvPayType.setText("支付宝");
                tvDoPay.setEnabled(true);
                tvDoPay.setBackgroundColor(getResources().getColor(R.color.red));
                payTypeWindow.dismiss();
                break;
            case R.id.cus_tv_wechat:

                ivAplipayCheck.setVisibility(View.GONE);
                ivWechatCheck.setVisibility(View.VISIBLE);
                tvPayType.setText("微信");
                payType = PayType.WX;
                tvDoPay.setEnabled(true);
                tvDoPay.setBackgroundColor(getResources().getColor(R.color.red));
                payTypeWindow.dismiss();
                break;
        }
    }

    @Override
    protected void onStop() {
        super.onStop();

        isStop = true;
    }
}
