package com.chinapnr.android.adapay_android;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.content.Intent;
import android.graphics.Rect;
import android.os.Bundle;
import android.os.Handler;
import android.support.design.widget.TabLayout;
import android.support.v4.content.ContextCompat;
import android.text.TextUtils;
import android.util.Log;
import android.view.SurfaceHolder;
import android.view.SurfaceView;
import android.view.View;
import android.view.animation.Animation;
import android.view.animation.TranslateAnimation;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;
import android.widget.TextView;
import android.widget.Toast;

import com.alibaba.fastjson.JSON;
import com.chinapnr.android.adapay.AdaPay;
import com.chinapnr.android.adapay.PayCallback;
import com.chinapnr.android.adapay.bean.Payment;
import com.chinapnr.android.adapay.bean.PayResult;
import com.chinapnr.android.adapay.bean.PayType;
import com.chinapnr.android.adapay_android.beans.respbean.BaseRespBean;
import com.chinapnr.android.adapay_android.network.PayNetWorkCallback;
import com.chinapnr.android.adapay_android.widgets.camera.CameraManager;
import com.chinapnr.android.adapay_android.widgets.decode.MainHandler;
import com.chinapnr.android.adapay_android.widgets.utils.BeepManager;
import com.chinapnr.android.adapay_android.widgets.DialogManager;

import java.lang.reflect.Field;

/**
 * Desc: 1:启动一个SurfaceView作为取景预览
 * 2:开启camera,在后台独立线程中完成扫描任务
 * 3:对解码返回的结果进行处理.
 * 4:释放资源
 */
public class CaptureActivity extends Activity implements SurfaceHolder.Callback {

    private static final String[] PAY_TYPE_ARRAY = {PayType.ALIPAY_SCAN, PayType.WX_SCAN};
    private String payType;
    private String amount;
    private boolean isStop;

    private MainHandler mainHandler;

    private CameraManager mCameraManager;
    private BeepManager beepManager;

    private SurfaceView scanPreview;
    private RelativeLayout scanContainer;
    private RelativeLayout scanCropView;

    private boolean isHasSurface = false;

    public Handler getHandler() {
        return mainHandler;
    }


    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_capture);

        payType = PayType.ALIPAY_SCAN;
        amount = getIntent().getStringExtra(QRCodePayActivity.AMOUNT);

        initView();
    }

    private void initView() {
        //标题栏
        findViewById(R.id.iv_back).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                finish();
            }
        });

        ((TextView) findViewById(R.id.tv_title)).setText("二维码扫描");

        //扫描区
        String amountStr;
        if (!TextUtils.isEmpty(amount)) {
            amountStr = "¥: " + amount;
        } else {
            amountStr = "自助联调";
        }

        ((TextView) findViewById(R.id.tv_tip)).setText(amountStr);

        scanPreview = findViewById(R.id.capture_preview);
        scanContainer = findViewById(R.id.capture_container);
        scanCropView = findViewById(R.id.capture_crop_view);
        ImageView scanLine = findViewById(R.id.capture_scan_line);
        isHasSurface = false;
        beepManager = new BeepManager(this);

        TranslateAnimation animation = new TranslateAnimation(Animation.RELATIVE_TO_PARENT, 0.0f, Animation
                .RELATIVE_TO_PARENT, 0.0f, Animation.RELATIVE_TO_PARENT, 0.0f, Animation.RELATIVE_TO_PARENT,
                0.9f);
        animation.setDuration(3000);
        animation.setRepeatCount(-1);
        animation.setRepeatMode(Animation.RESTART);
        scanLine.startAnimation(animation);

        //底部 tablayout
        TabLayout tabLayout = findViewById(R.id.tablayout);

        if (TextUtils.isEmpty(amount)) {
            //如果金额为空，说明是自助联调模式
            tabLayout.setVisibility(View.GONE);
        }

        tabLayout.addTab(tabLayout.newTab().setText(getResources().getString(R.string.alipay)));
        tabLayout.addTab(tabLayout.newTab().setText(getResources().getString(R.string.wechat)));
        LinearLayout linearLayout = (LinearLayout) tabLayout.getChildAt(0);
        linearLayout.setShowDividers(LinearLayout.SHOW_DIVIDER_MIDDLE);
        linearLayout.setDividerDrawable(ContextCompat.getDrawable(this, R.drawable.divider_vertical));
        linearLayout.setDividerPadding(40);

        tabLayout.addOnTabSelectedListener(new TabLayout.OnTabSelectedListener() {
            @Override
            public void onTabSelected(TabLayout.Tab tab) {

                payType = PAY_TYPE_ARRAY[tab.getPosition()];
            }

            @Override
            public void onTabUnselected(TabLayout.Tab tab) {

            }

            @Override
            public void onTabReselected(TabLayout.Tab tab) {

            }
        });
    }

    @Override
    protected void onResume() {
        super.onResume();

        isStop = false;

        SurfaceHolder mHolder = scanPreview.getHolder();
        mCameraManager = new CameraManager(getApplication());
        if (isHasSurface) {
            initCamera(mHolder);
        } else {
            mHolder.addCallback(this);
            mHolder.setType(SurfaceHolder.SURFACE_TYPE_PUSH_BUFFERS);
        }
    }

    private void initCamera(SurfaceHolder surfaceHolder) {
        mainHandler = null;
        try {
            mCameraManager.openDriver(surfaceHolder);
            if (mainHandler == null) {
                mainHandler = new MainHandler(this, mCameraManager);
            }
        } catch (Exception ioe) {
            Log.e(Config.TAG, "Unexpected error initializing camera");
        }

    }

    private PayNetWorkCallback callback = new PayNetWorkCallback<BaseRespBean>() {
        @Override
        public void onSuccess(BaseRespBean respObj) {

            if (respObj == null) {
                Toast.makeText(CaptureActivity.this, "支付信息为空", Toast.LENGTH_SHORT).show();
                return;
            }

            String paymentInfo = respObj.getPayment();
            final Payment paymentObj = JSON.parseObject(paymentInfo, Payment.class);

            AdaPay.doPay(CaptureActivity.this, 180, respObj.getPayment(), new PayCallback() {
                @Override
                public void onPayment(PayResult payResult) {

                    DialogManager.dismiss();

                    Intent intent = new Intent(CaptureActivity.this, PayResultActivity.class);
                    intent.putExtra(PayResultActivity.PAYMENT_INFO, paymentObj);
                    intent.putExtra(PayResultActivity.TRADE_CODE, payResult.getResultCode());
                    intent.putExtra(PayResultActivity.TRADE_MSG, payResult.getResultMsg());
                    startActivity(intent);

                    finish();
                }
            });
        }

        @Override
        public void onFail(BaseRespBean respObj) {
            DialogManager.dismiss();
            String paymentInfo = respObj.getPayment();
            final Payment paymentObj = JSON.parseObject(paymentInfo, Payment.class);
            Toast.makeText(CaptureActivity.this, paymentObj.getError_msg(), Toast.LENGTH_SHORT).show();
        }

        @Override
        public void onFail(String respMsg) {
            DialogManager.dismiss();
            Toast.makeText(CaptureActivity.this, respMsg, Toast.LENGTH_SHORT).show();
        }
    };

    /**
     * 进行自助联调
     */
    private void doAutoTest(String paymentInfo) {
        final Payment paymentObj;

        try {
            paymentObj = JSON.parseObject(paymentInfo, Payment.class);
        } catch (Exception e) {
            e.printStackTrace();
            Toast.makeText(this, "二维码数据无效,请重新扫描", Toast.LENGTH_SHORT).show();
            return;
        }

        switch (paymentObj.getPay_channel()) {
            //正扫去显示二维码，其他支付方式直接调用 sdk
            case PayType.ALIPAY_QR:
            case PayType.WX_QR:

                Intent intent = new Intent(this, QRCodePayActivity.class);
                intent.putExtra(PayResultActivity.PAYMENT_INFO, paymentObj);
                startActivity(intent);
                finish();
                break;
            case PayType.ALIPAY:
            case PayType.ALIPAY_SCAN:
            case PayType.WX:
            case PayType.WX_SCAN:
                DialogManager.showDialog(this, true);
                AdaPay.doPay(this, paymentInfo, new PayCallback() {
                    @Override
                    public void onPayment(PayResult payResult) {
                        if (isStop) {
                            return;
                        }

                        DialogManager.dismiss();

                        Intent intent = new Intent(CaptureActivity.this, PayResultActivity.class);
                        intent.putExtra(PayResultActivity.PAYMENT_INFO, paymentObj);
                        intent.putExtra(PayResultActivity.TRADE_CODE, payResult.getResultCode());
                        intent.putExtra(PayResultActivity.TRADE_MSG, payResult.getResultMsg());
                        startActivity(intent);

                        finish();
                    }
                });
                break;
        }
    }

    @Override
    protected void onStop() {
        super.onStop();

        isStop = true;
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();

        releaseCamera();

        if (!isHasSurface) {
            scanPreview.getHolder().removeCallback(this);
        }
    }

    private void releaseCamera() {
        if (null != mainHandler) {
            //关闭聚焦,停止预览,清空预览回调,quit子线程looper
            mainHandler.quitSynchronously();
            mainHandler = null;
        }
        //关闭声音
        if (null != beepManager) {
            Log.e(Config.TAG, "releaseCamera: beepManager release");
            beepManager.releaseRing();
            beepManager = null;
        }
        //关闭相机
        if (mCameraManager != null) {
            mCameraManager.closeDriver();
            mCameraManager = null;
        }
    }

    /**
     * 处理扫描结果
     *
     * @param result 二维码内容
     */
    public void checkResult(final String result) {
        if (beepManager != null) {
            beepManager.startRing();
        }

        mainHandler.postDelayed(new Runnable() {
            @Override
            public void run() {
                if (TextUtils.isEmpty(amount)) {
                    doAutoTest(result);
                    return;
                }
                TradeRequest.requestPayment(CaptureActivity.this, amount, payType, result, callback);
            }
        }, beepManager.getTimeDuration());
    }

    /**
     * 初始化截取的矩形区域
     */
    public Rect initCrop() {
        int cameraWidth = 0;
        int cameraHeight = 0;
        if (null != mCameraManager) {
            cameraWidth = mCameraManager.getCameraResolution().y;
            cameraHeight = mCameraManager.getCameraResolution().x;
        }

        //获取布局中扫描框的位置信息
        int[] location = new int[2];
        scanCropView.getLocationInWindow(location);

        int cropLeft = location[0];
        int cropTop = location[1] - getStatusBarHeight();

        int cropWidth = scanCropView.getWidth();
        int cropHeight = scanCropView.getHeight();

        // 获取布局容器的宽高
        int containerWidth = scanContainer.getWidth();
        int containerHeight = scanContainer.getHeight();

        // 计算最终截取的矩形的左上角顶点x坐标
        int x = cropLeft * cameraWidth / containerWidth;
        // 计算最终截取的矩形的左上角顶点y坐标
        int y = cropTop * cameraHeight / containerHeight;

        // 计算最终截取的矩形的宽度
        int width = cropWidth * cameraWidth / containerWidth;
        // 计算最终截取的矩形的高度
        int height = cropHeight * cameraHeight / containerHeight;

        // 生成最终的截取的矩形
        return new Rect(x, y, width + x, height + y);
    }

    private int getStatusBarHeight() {
        try {
            @SuppressLint("PrivateApi") Class<?> c = Class.forName("com.android.internal.R$dimen");
            Object obj = c.newInstance();
            Field field = c.getField("status_bar_height");
            int x = Integer.parseInt(field.get(obj).toString());
            return getResources().getDimensionPixelSize(x);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return 0;
    }

    //-------------------------SurfaceHolder Callback-------------------------
    @Override
    public void surfaceCreated(SurfaceHolder holder) {
        if (holder == null) {
            Log.e(Config.TAG, "*** 没有添加SurfaceHolder的Callback");
        }

        if (!isHasSurface) {
            isHasSurface = true;
            initCamera(holder);
        }
    }

    @Override
    public void surfaceChanged(SurfaceHolder holder, int format, int width, int height) {
        Log.e(Config.TAG, "surfaceChanged: ");

    }

    @Override
    public void surfaceDestroyed(SurfaceHolder holder) {
        isHasSurface = false;

    }
    //-------------------------SurfaceHolder Callback-------------------------
}