package com.chinapnr.android.adapay_android;

import android.Manifest;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.os.Build;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.v4.content.PermissionChecker;
import android.support.v7.app.AppCompatActivity;
import android.text.TextUtils;
import android.view.View;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

public class InputAmountActivity extends AppCompatActivity implements View.OnClickListener {
    public static final String PAY_TYPE = "pay_type";
    public static final String PAY_TYPE_QR = "QR";
    public static final String PAY_TYPE_SCAN = "SCAN";

    private static final int PERMISSION_REQUEST_ID = 0x1001;

    private EditText etAmount;

    private String payType;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_input_amount);

        payType = getIntent().getStringExtra(PAY_TYPE);
        findViewById(R.id.iv_back).setOnClickListener(this);
        ((TextView) findViewById(R.id.tv_title)).setText("二维码收款");
        etAmount = findViewById(R.id.et_amount);
        findViewById(R.id.btn_next_step).setOnClickListener(this);
    }

    @Override
    public void onClick(View view) {
        int viewId = view.getId();

        switch (viewId) {
            case R.id.iv_back:
                finish();
                break;

            case R.id.btn_next_step:

                String amount = etAmount.getText().toString();
                if (TextUtils.isEmpty(amount)) {
                    Toast.makeText(this, "请输入有效金额", Toast.LENGTH_SHORT).show();
                    return;
                }

                if (PAY_TYPE_SCAN.equals(payType)) {
                    //如果为自助联调需要检查权限
                    requestPermission();
                    return;
                }

                Intent intent = new Intent(this, QRCodePayActivity.class);
                intent.putExtra(QRCodePayActivity.AMOUNT, amount);
                startActivity(intent);
                break;
        }
    }

    private void requestPermission() {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            if (PermissionChecker.checkSelfPermission(
                    this, Manifest.permission.CAMERA) == PackageManager.PERMISSION_DENIED) {
                String[] permissions = {Manifest.permission.CAMERA};
                requestPermissions(permissions, PERMISSION_REQUEST_ID);
                return;
            }
        }

        Intent intent = new Intent();
        intent.putExtra(QRCodePayActivity.AMOUNT, etAmount.getText().toString());
        intent.setClass(this, CaptureActivity.class);
        startActivity(intent);
    }

    @Override
    public void onRequestPermissionsResult(int requestCode, @NonNull String[] permissions, @NonNull int[] grantResults) {

        if (requestCode != PERMISSION_REQUEST_ID) {
            Toast.makeText(this, "请打开相机权限", Toast.LENGTH_SHORT).show();
            return;
        }

        if (grantResults[0] == PackageManager.PERMISSION_GRANTED) {
            Intent intent = new Intent();
            intent.setClass(this, CaptureActivity.class);
            startActivity(intent);
        } else {
            Toast.makeText(this, "请打开相机权限", Toast.LENGTH_SHORT).show();
        }
    }
}
