package com.chinapnr.android.adapay_android;

import android.Manifest;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.os.Build;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.v4.content.PermissionChecker;
import android.support.v7.app.AppCompatActivity;
import android.view.View;
import android.widget.Toast;

public class MainActivity extends AppCompatActivity implements View.OnClickListener {
    private static final int PERMISSION_REQUEST_ID = 0x1001;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        findViewById(R.id.btn_app_payment).setOnClickListener(this);
        findViewById(R.id.btn_qrcode_payment).setOnClickListener(this);
        findViewById(R.id.btn_scan_qrcode).setOnClickListener(this);
        findViewById(R.id.btn_auto_test).setOnClickListener(this);
        findViewById(R.id.tv_setting).setOnClickListener(this);
    }

    @Override
    public void onClick(View view) {
        int viewId = view.getId();
        Intent intent = new Intent();

        switch (viewId) {
            case R.id.btn_app_payment:
                //app 支付
                intent.setClass(this, AppPayActivity.class);
                break;

            case R.id.btn_qrcode_payment:
                //正扫收款
                intent.putExtra(InputAmountActivity.PAY_TYPE, InputAmountActivity.PAY_TYPE_QR);
                intent.setClass(this, InputAmountActivity.class);
                break;

            case R.id.btn_scan_qrcode:
                //反扫收款
                intent.putExtra(InputAmountActivity.PAY_TYPE, InputAmountActivity.PAY_TYPE_SCAN);
                intent.setClass(this, InputAmountActivity.class);
                break;

            case R.id.btn_auto_test:
                requestPermission();
                intent = null;
                break;

            case R.id.tv_setting:
                //demo 设置
                intent.setClass(this, SettingActivity.class);
                break;
        }

        if (intent == null) {
            return;
        }
        startActivity(intent);
    }

    private void requestPermission() {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            if (PermissionChecker.checkSelfPermission(
                    this, Manifest.permission.CAMERA) == PackageManager.PERMISSION_DENIED) {
                String[] permissions = {Manifest.permission.CAMERA};
                requestPermissions(permissions, PERMISSION_REQUEST_ID);
                return;
            }
        }

        Intent intent = new Intent();
        intent.setClass(this, CaptureActivity.class);
        startActivity(intent);
    }

    @Override
    public void onRequestPermissionsResult(int requestCode, @NonNull String[] permissions, @NonNull int[] grantResults) {

        if (requestCode != PERMISSION_REQUEST_ID) {
            Toast.makeText(this, "请打开相机权限", Toast.LENGTH_SHORT).show();
            return;
        }

        if (grantResults[0] == PackageManager.PERMISSION_GRANTED) {
            Intent intent = new Intent();
            intent.setClass(this, CaptureActivity.class);
            startActivity(intent);
        } else {
            Toast.makeText(this, "请打开相机权限", Toast.LENGTH_SHORT).show();
        }
    }
}
