package com.chinapnr.android.adapay_android;

import android.annotation.SuppressLint;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.text.Spannable;
import android.text.SpannableString;
import android.text.Spanned;
import android.text.style.AbsoluteSizeSpan;
import android.text.style.StyleSpan;
import android.view.View;
import android.widget.TextView;

import com.chinapnr.android.adapay.bean.Payment;
import com.chinapnr.android.adapay.bean.PayType;
import com.chinapnr.android.adapay.bean.ResponseCode;

import java.text.SimpleDateFormat;
import java.util.Date;

public class PayResultActivity extends AppCompatActivity {

    public static final String PAYMENT_INFO = "payment_info";
    public static final String TRADE_CODE = "trade_code";
    public static final String TRADE_MSG = "trade_msg";
    private Payment payment;

    private String payResultCode;
    private String payResultMsg;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_pay_result);

        payment = (Payment) getIntent().getSerializableExtra(PAYMENT_INFO);
        payResultCode = getIntent().getStringExtra(TRADE_CODE);
        payResultMsg = getIntent().getStringExtra(TRADE_MSG);
        initView();
    }

    @SuppressLint("SimpleDateFormat")
    private void initView() {
        findViewById(R.id.iv_back).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                finish();
            }
        });
        ((TextView) findViewById(R.id.tv_title)).setText("支付结果");

        TextView tvResult = findViewById(R.id.tv_result);
        TextView tvMessage = findViewById(R.id.tv_trade_msg);

        String payResult = "";
        switch (payResultCode) {
            case ResponseCode.SUCCESS:
                payResult = "支付成功";
                payResultMsg = "支付成功";
                break;
            case ResponseCode.PENDING:
                payResult = "支付处理中";
                payResultMsg = "支付处理中";
                break;
            case ResponseCode.FAILED:
                payResult = "支付失败";
                break;
        }
        tvResult.setText(payResult);
        tvMessage.setText(payResultMsg);

        TextView tvAmount = findViewById(R.id.tv_amount);
        Spannable amountStr = new SpannableString("¥ " + payment.getPay_amt());
        amountStr.setSpan(new AbsoluteSizeSpan(75), 1, amountStr.length(), Spannable.SPAN_EXCLUSIVE_EXCLUSIVE);
        amountStr.setSpan(new StyleSpan(android.graphics.Typeface.BOLD), 1, amountStr.length(), Spanned.SPAN_EXCLUSIVE_EXCLUSIVE);
        tvAmount.setText(amountStr);

        TextView tvTradeTime = findViewById(R.id.tv_trade_time);
        String tradeTime = "";
        try {
            Date orderDateEnd = new SimpleDateFormat("yyyyMMddHHmmss").parse(payment.getCreated());
            tradeTime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(orderDateEnd);

        } catch (Exception e) {
            e.printStackTrace();
        }

        tvTradeTime.setText(tradeTime);

        TextView tvOrderNo = findViewById(R.id.tv_seq_id);
        tvOrderNo.setText(payment.getOrder_no());


        TextView tvPayType = findViewById(R.id.tv_pay_type);
        String payType = "";
        switch (payment.getPay_channel()) {
            case PayType.ALIPAY:
                payType = "支付宝支付";
                break;
            case PayType.ALIPAY_QR:
                payType = "支付宝二维码支付";
                break;
            case PayType.ALIPAY_SCAN:
                payType = "支付宝扫码收款";
                break;
            case PayType.WX:
                payType = "微信支付";
                break;
            case PayType.WX_QR:
                payType = "微信二维码支付";
                break;
            case PayType.WX_SCAN:
                payType = "微信扫码收款";
                break;
        }
        tvPayType.setText(payType);
    }
}
