package com.chinapnr.android.adapay_android;

import android.content.Intent;
import android.os.Bundle;
import android.support.design.widget.TabLayout;
import android.support.v4.content.ContextCompat;
import android.support.v7.app.AppCompatActivity;
import android.text.Spannable;
import android.text.SpannableString;
import android.text.Spanned;
import android.text.style.AbsoluteSizeSpan;
import android.text.style.StyleSpan;
import android.view.View;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

import com.alibaba.fastjson.JSON;
import com.chinapnr.android.adapay.AdaPay;
import com.chinapnr.android.adapay.PayCallback;
import com.chinapnr.android.adapay.bean.Payment;
import com.chinapnr.android.adapay.bean.PayResult;
import com.chinapnr.android.adapay.bean.PayType;
import com.chinapnr.android.adapay_android.beans.respbean.BaseRespBean;
import com.chinapnr.android.adapay_android.network.PayNetWorkCallback;
import com.chinapnr.android.adapay_android.utils.QRCodeTools;
import com.chinapnr.android.adapay_android.widgets.DialogManager;

public class QRCodePayActivity extends AppCompatActivity {

    public static final String AMOUNT = "amount";
    private static final String[] PAY_TYPE_ARRAY = {PayType.ALIPAY_QR, PayType.WX_QR};

    private String amount;
    private ImageView ivQrCode;
    //标识此页面是否走过 onStop 生命周期
    private boolean isStop;
    private String lastOrderNum;
    private Payment paymentObj;

    private PayNetWorkCallback callback = new PayNetWorkCallback<BaseRespBean>() {
        @Override
        public void onSuccess(BaseRespBean respObj) {

            DialogManager.dismiss();

            if (respObj == null) {
                ivQrCode.setVisibility(View.INVISIBLE);
                Toast.makeText(QRCodePayActivity.this, "支付信息为空", Toast.LENGTH_SHORT).show();
                return;
            }

            String paymentInfo = respObj.getPayment();
            final Payment paymentObj = JSON.parseObject(paymentInfo, Payment.class);
            Payment.Expend extra = paymentObj.getExpend();

            lastOrderNum = paymentObj.getOrder_no();

            if (extra == null) {
                Toast.makeText(QRCodePayActivity.this, "支付信息为空", Toast.LENGTH_SHORT).show();
                ivQrCode.setVisibility(View.INVISIBLE);
                return;
            }

            String qrcodeUrl = extra.getQrcode_url();

            ivQrCode.setVisibility(View.VISIBLE);
            ivQrCode.setImageBitmap(QRCodeTools.createQRCode(qrcodeUrl));

            AdaPay.doPay(QRCodePayActivity.this, 180, respObj.getPayment(), new PayCallback() {
                @Override
                public void onPayment(PayResult payResult) {
                    //页面多次刷新二维码，只处理最后一次交易的回调，如果页面经过跳转，也不处理
                    if (!lastOrderNum.equals(payResult.getOrderNo()) || isStop) {
                        return;
                    }

                    Intent intent = new Intent(QRCodePayActivity.this, PayResultActivity.class);
                    intent.putExtra(PayResultActivity.PAYMENT_INFO, paymentObj);
                    intent.putExtra(PayResultActivity.TRADE_CODE, payResult.getResultCode());
                    intent.putExtra(PayResultActivity.TRADE_MSG, payResult.getResultMsg());
                    startActivity(intent);

                    finish();
                }
            });
        }

        @Override
        public void onFail(BaseRespBean respObj) {
            DialogManager.dismiss();
            ivQrCode.setVisibility(View.INVISIBLE);
            Toast.makeText(QRCodePayActivity.this, "支付失败", Toast.LENGTH_SHORT).show();
        }

        @Override
        public void onFail(String respMsg) {
            DialogManager.dismiss();
            ivQrCode.setVisibility(View.INVISIBLE);
            Toast.makeText(QRCodePayActivity.this, respMsg, Toast.LENGTH_SHORT).show();
        }
    };

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_qrcode_pay);

        amount = getIntent().getStringExtra(AMOUNT);
        paymentObj = (Payment) getIntent().getSerializableExtra(PayResultActivity.PAYMENT_INFO);

        initView();
    }

    private void initView() {
        findViewById(R.id.iv_back).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                finish();
            }
        });
        ((TextView) findViewById(R.id.tv_title)).setText("二维码收款");

        TabLayout tabLayout = findViewById(R.id.tablayout);
        tabLayout.addTab(tabLayout.newTab().setText(getResources().getString(R.string.alipay)));
        tabLayout.addTab(tabLayout.newTab().setText(getResources().getString(R.string.wechat)));
        LinearLayout linearLayout = (LinearLayout) tabLayout.getChildAt(0);
        linearLayout.setShowDividers(LinearLayout.SHOW_DIVIDER_MIDDLE);
        linearLayout.setDividerDrawable(ContextCompat.getDrawable(this, R.drawable.divider_vertical));
        linearLayout.setDividerPadding(40);

        tabLayout.addOnTabSelectedListener(new TabLayout.OnTabSelectedListener() {
            @Override
            public void onTabSelected(TabLayout.Tab tab) {
                TradeRequest.requestPayment(QRCodePayActivity.this, amount,
                        PAY_TYPE_ARRAY[tab.getPosition()], callback);
            }

            @Override
            public void onTabUnselected(TabLayout.Tab tab) {

            }

            @Override
            public void onTabReselected(TabLayout.Tab tab) {

            }
        });

        ivQrCode = findViewById(R.id.iv_qr_code);

        if (paymentObj != null) {
            //payment 对象不为空，说明是自助联调页面跳转来的
            tabLayout.setVisibility(View.GONE);
            amount = paymentObj.getPay_amt();
            String qrcodeUrl = paymentObj.getExpend().getQrcode_url();
            ivQrCode.setImageBitmap(QRCodeTools.createQRCode(qrcodeUrl));
            AdaPay.doPay(QRCodePayActivity.this, 60, JSON.toJSONString(paymentObj), new PayCallback() {
                @Override
                public void onPayment(PayResult payResult) {
                    //如果页面经过跳转，不处理
                    if (isStop) {
                        return;
                    }

                    Intent intent = new Intent(QRCodePayActivity.this, PayResultActivity.class);
                    intent.putExtra(PayResultActivity.PAYMENT_INFO, paymentObj);
                    intent.putExtra(PayResultActivity.TRADE_CODE, payResult.getResultCode());
                    intent.putExtra(PayResultActivity.TRADE_MSG, payResult.getResultMsg());
                    startActivity(intent);
                    finish();
                }
            });
        } else {
            TradeRequest.requestPayment(this, amount, PayType.ALIPAY_QR, callback);
        }

        Spannable amountStr = new SpannableString("¥ " + amount);
        amountStr.setSpan(new AbsoluteSizeSpan(75), 1, amountStr.length(), Spannable.SPAN_EXCLUSIVE_EXCLUSIVE);
        amountStr.setSpan(new StyleSpan(android.graphics.Typeface.BOLD), 1, amountStr.length(), Spanned.SPAN_EXCLUSIVE_EXCLUSIVE);
        ((TextView) findViewById(R.id.tv_amount)).setText(amountStr);
    }

    @Override
    protected void onStart() {
        super.onStart();

        isStop = false;
    }

    @Override
    protected void onStop() {
        super.onStop();

        isStop = true;
    }
}
